﻿using ProjectOptika.Scripts.Entities;
using ProjectOptika.Scripts.Entities.Enums;
using ProjectOptika.Scripts.Repositories;

namespace ProjectOptika.Scripts.Forms
{
    public partial class FormAccessory : Form
    {
        private readonly IAccessoriesRepository _accessoriesRepositories;

        private int? _accessoriesID;

        public int ID
        {
            set
            {
                try
                {
                    var accessory = _accessoriesRepositories.GetAccessoriesByID(value);

                    if (accessory == null) throw new InvalidDataException(nameof(accessory));

                    _accessoriesID = accessory.ID;
                    textBoxBrand.Text = accessory.Brand;
                    textBoxName.Text = accessory.Name;
                    numericUpDownCost.Value = accessory.Cost;
                    numericUpDownAvailabilityStore.Value = accessory.AvailabilityStore;
                    numericUpDownStockAvailability.Value = accessory.StockAvailability;
                    dateTimePickerDeliveryDate.Value = accessory.DeliveryDate;

                    comboBoxCategoryName.SelectedIndex = (int)accessory.CategoryName;
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }
        }

        public FormAccessory(IAccessoriesRepository accessoriesRepositories)
        {
            InitializeComponent();

            _accessoriesRepositories = accessoriesRepositories
                ?? throw new ArgumentNullException(nameof(accessoriesRepositories));

            comboBoxCategoryName.DataSource = Enum.GetValues(typeof(CategoryType));
        }

        private void ButtonSave_Click(object sender, EventArgs e)
        {
            try
            {
                if (comboBoxCategoryName.SelectedIndex < 1 || string.IsNullOrEmpty(textBoxName.Text) || string.IsNullOrEmpty(textBoxBrand.Text))
                {
                    throw new Exception("Имеются незаполненные данные");
                }

                if (_accessoriesID.HasValue)
                {
                    _accessoriesRepositories.UpdateAccessories(CreateAccessories(_accessoriesID.Value));
                }
                else
                {
                    _accessoriesRepositories.CreateAccessories(CreateAccessories(0));
                }
                Close();
            }
            catch (System.Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при получении сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void ButtonCancel_Click(object sender, EventArgs e)
        {
            Close();
        }

        private Accessories CreateAccessories(int id)
        {
            return Accessories.CreateEntity(id, textBoxName.Text, textBoxBrand.Text, (int)numericUpDownCost.Value, (int)numericUpDownStockAvailability.Value, (int)numericUpDownAvailabilityStore.Value, dateTimePickerDeliveryDate.Value, (CategoryType)comboBoxCategoryName.SelectedIndex);
        }
    }
}
