﻿using ProjectOptika.Scripts.Repositories;
using Unity;

namespace ProjectOptika.Scripts.Forms
{
    public partial class FormSpecifications : Form
    {
        private readonly IUnityContainer _container;

        private readonly ISpecificationsRepository _specificationRepositories;

        public FormSpecifications(IUnityContainer container, ISpecificationsRepository lensRepositories)
        {
            InitializeComponent();

            _container = container ??
                throw new ArgumentException(nameof(container));

            _specificationRepositories = lensRepositories ??
                throw new ArgumentException(nameof(lensRepositories));
        }

        private void Form_Load(object sender, EventArgs e)
        {
            try
            {
                LoadList();
            }
            catch (System.Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при загрузке", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void ButtonAdd_Click(object sender, EventArgs e)
        {
            try
            {
                _container.Resolve<FormSpecification>().ShowDialog();
                LoadList();
            }
            catch (System.Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при загрузке", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void ButtonUpdate_Click(object sender, EventArgs e)
        {
            if (!TryGetIdentifierFromSelectedRows(out var findID)) return;

            try
            {
                var form = _container.Resolve<FormSpecification>();
                form.ID = findID;
                form.ShowDialog();
                LoadList();
            }
            catch (System.Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при изменении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void ButtonRemove_Click(object sender, EventArgs e)
        {
            if (!TryGetIdentifierFromSelectedRows(out var findID)) return;

            if (MessageBox.Show("Удалить запись?", "Удалить", MessageBoxButtons.YesNo) != DialogResult.Yes) return;

            try
            {
                _specificationRepositories.DeleteSpecifications(findID);
                LoadList();
            }
            catch (System.Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при удалении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void LoadList() => dataGridView.DataSource = _specificationRepositories.GetSpecifications();

        private bool TryGetIdentifierFromSelectedRows(out int id)
        {
            id = 0;
            if (dataGridView.SelectedRows.Count < 1)
            {
                MessageBox.Show("Нет выбранной записи", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return false;
            }

            id = Convert.ToInt32(dataGridView.SelectedRows[0].Cells["ID"].Value);
            return true;
        }
    }
}
